@@ -35,10 +35,10 @@ sub CLI_RUN ( $self, $opt, $arg, $rest ) {
 
     if ( !$dist->par_cfg ) {
         if ( P->term->prompt( q[Create PAR profile?], [qw[yes no]], enter => 1 ) eq 'yes' ) {
-            require Pcore::Util::File::Tree;
+            require Pcore::Lib::File::Tree;
 
             # copy files
-            my $files = Pcore::Util::File::Tree->new;
+            my $files = Pcore::Lib::File::Tree->new;
 
             $files->add_dir( $ENV->{share}->get_location('/Pcore/dist-tmpl') . '/par/' );
 
