@@ -1,7 +1,7 @@
 package Pcore::HTTP;
 
 use Pcore -const, -export;
-use Pcore::Util::Scalar qw[is_ref is_plain_coderef is_blessed_ref is_coderef is_plain_hashref is_plain_arrayref];
+use Pcore::Lib::Scalar qw[is_ref is_plain_coderef is_blessed_ref is_coderef is_plain_hashref is_plain_arrayref];
 use Pcore::Handle qw[:ALL];
 use Pcore::HTTP::Response;
 use Pcore::HTTP::Cookies;
@@ -705,7 +705,7 @@ sub _read_data ( $h, $args, $res ) {
 }
 
 sub _get_on_progress_cb (%args) {
-    require Pcore::Util::Term::Progress;
+    require Pcore::Lib::Term::Progress;
 
     return sub ( $content_length, $bytes_received ) {
         state $indicator;
@@ -715,7 +715,7 @@ sub _get_on_progress_cb (%args) {
 
             $args{total} = $content_length;
 
-            $indicator = Pcore::Util::Term::Progress::get_indicator(%args);
+            $indicator = Pcore::Lib::Term::Progress::get_indicator(%args);
         }
         else {
             $indicator->update( value => $bytes_received );
